#ifndef ENEMY_H_INCLUDED
#define ENEMY_H_INCLUDED

#include "common.h"
#include "graphics.h"
#include "sound.h"
#include "input.h"
#include "enemy.h"
#include "bullet.h"
#include "explosion.h"

class Match;

struct Enemy_type {
	ho::opengl::Texture* 	texture				= 0;
	float					shoot_offset		= 0;
	float					move_speed			= 0;
	float					turn_speed			= 0;
	float 					full_health			= 0;
	float 					damaged_offset 		= 0;
	ho::vector2f 			dimensions;
	ho::vector2f 			sprite_offset;
	int 					score_killed 		= 0;
	float 					bullet_damage 		= 0;
	float 					bullet_speed 		= 0;
};

class Enemy {
public:
												Enemy(Pipeline* PIPELINE, Match* MATCH, Enemy_type* TYPE);
												~Enemy();

	void 										update();
	void 										render();
	std::pair<ho::vector2f, ho::vector2f> 	get_collision();
	void										damage(float AMOUNT);
	bool										dead();

private:
	Pipeline* 					pipeline;
	Match* 						match;
	Enemy_type* 				type;
	ho::opengl::Sprite 			sprite;
	ho::vector2f 				position;
	ho::Timer 					life_timer;
	ho::Timer 					shoot_timer;
	ho::Timer 					damaged_timer;
	bool 						fire;
	float						current_angle;
	float 						move_angle;
	ho::Timer 					choose_angle;
	bool 						killed;
	float 						health;
	ho::opengl::Primitive2d 	health_bar_green;
	ho::opengl::Primitive2d 	health_bar_red;
	ho::opengl::Primitive2d 	health_bar_border;
};

#endif // ENEMY_H_INCLUDED
