#include "game.h"

Game::Game(Pipeline* PIPELINE) {
	pipeline 	= PIPELINE;
	menu 		= 0;
	match 		= 0;
	game_state 	= MAINMENU;
	pipeline->sound->play_sound("music");
	high_score 	= 0;
}

Game::~Game() {
	if(menu)
		delete menu;

	if(match)
		delete match;
}

void Game::update() {
	pipeline->screen_bounds = ho::vector4f(0, 0, pipeline->resolution[0], pipeline->resolution[1]);

	// Back to menu
	if(pipeline->input->keyboard_mem[pipeline->keys.ESC])
		game_state = States::MAINMENU;

	if(game_state == States::MAINMENU) {
		if(!menu)
			menu = new MainMenu(pipeline);

		if(match) {
			delete match;
			match = 0;
		}

		menu->update();

		// If menu state is to start the match, set the game state to match
		if(menu->state() == MainMenu::States::START)
			game_state = States::MATCH;
	}
	else if(game_state == States::MATCH) {
		if(!match)
			match = new Match(pipeline, this);

		if(menu) {
			delete menu;
			menu = 0;
		}

		match->update();
	}
}

void Game::render() {
	if(game_state == States::MAINMENU && menu) {
		menu->render();
	}
	else if(game_state == States::MATCH && match) {
		match->render();
	}
}

void Game::set_highscore(int SCORE) {
	if(SCORE > high_score)
		high_score = SCORE;
}

int Game::get_highscore() {
	return high_score;
}
