#include "graphics.h"

Graphics::~Graphics() {
	// Delete textures
	for(auto it = textures.begin(); it != textures.end(); ++it)
		delete it->second;

	// Delete fonts
	for(auto it = fonts.begin(); it != fonts.end(); ++it)
		delete it->second;
}

bool Graphics::load(ho::Config &FACTORY) {
	// Textures
	auto textures_section = FACTORY.get_section("textures");

	if(!textures_section) {
		std::cout << "[!] Graphics::load: Could not find [textures] section\n";

		return false;
	}

	for(auto it = textures_section->begin(); it != textures_section->end(); ++it) {
		if(!import_png(it->second, it->first))
			return false;
	}

	// Fonts
	auto fonts_section = FACTORY.get_section("fonts");

	if(!fonts_section) {
		std::cout << "[!] Graphics::load: Could not find [fonts] section\n";

		return false;
	}

	for(auto it = fonts_section->begin(); it != fonts_section->end(); ++it) {
		if(!import_truetype(it->second, it->first, 20))
			return false;
	}

	return true;
}

ho::opengl::Texture* Graphics::get_texture(ho::String NAME) {
	auto find = textures.find(NAME);

	if(find == textures.end()) {
		std::cout << "[!] Graphics::get_texture: Could not find \"" << NAME << "\"\n";

		return 0;
	}

	return find->second;
}

ho::opengl::TrueType* Graphics::get_font(ho::String NAME) {
	auto find = fonts.find(NAME);

	if(find == fonts.end()) {
		std::cout << "[!] Graphics::get_font: Could not find \"" << NAME << "\"\n";

		return 0;
	}

	return find->second;
}

bool Graphics::import_png(ho::String FILENAME, ho::String NAME) {
	// Load PNG
	std::vector<unsigned char> rgba;
	unsigned width, height;
	unsigned status = lodepng::decode(rgba, width, height, FILENAME.c_str());

	if(status != 0) {
		std::cout << "[!] Graphics::import_png: \"" << FILENAME << "\" could not be found.\n";

		return false;
	}

	ho::opengl::Texture* texture = new ho::opengl::Texture;
	texture->load_rgba(rgba, ho::vector2(width, height), false);
	textures.insert(std::pair<ho::String, ho::opengl::Texture*>(NAME, texture));

	return true;
}

bool Graphics::import_truetype(ho::String FILENAME, ho::String NAME, int SIZE) {
	ho::opengl::TrueType* font = new ho::opengl::TrueType;

	if(font->load_face(FILENAME, SIZE) != 0) {
		delete font;
		std::cout << "[!] Graphics::import_truetype: \"" << FILENAME << "\" could not be found.\n";

		return false;
	}

	fonts.insert(std::pair<ho::String, ho::opengl::TrueType*>(NAME, font));

	return true;
}
