#include "input.h"

Input::Input(Pipeline* PIPELINE) {
	pipeline = PIPELINE;
	memset(keyboard_mem, 0, sizeof(keyboard_mem));
	memset(mouse_mem, 0, sizeof(mouse_mem));
}

void Input::update(std::vector<ho::Application::Key> KEYBOARD, std::vector<ho::Application::Mouse> MOUSE, ho::vector2 CURSOR_POSITION) {
	/// Keyboard and mouse mem are used to see if something is HELD
	mouse.clear();
	keyboard.clear();
	mouse = MOUSE;
	keyboard = KEYBOARD;

	// Stretch the cursor coordinates if the game is set to stretch (graphics)
	if(pipeline->stretch && pipeline->window_dimensions[0] > 0) {
		cursor_position[0] = CURSOR_POSITION[0] * pipeline->resolution[0] / pipeline->window_dimensions[0];
		cursor_position[1] = CURSOR_POSITION[1] * pipeline->resolution[1] / pipeline->window_dimensions[1];
	} else
		cursor_position = ho::vector2f(CURSOR_POSITION[0], CURSOR_POSITION[1]);

	// Keyboard mem
	for(auto it = keyboard.begin(); it != keyboard.end(); ++it)
		keyboard_mem[it->key] = (it->action == ho::Application::Key::Actions::ENGAGED);

	// Go through each mouse event and change them if necessary
	for(auto it = mouse.begin(); it != mouse.end(); ++it) {
		ho::vector4f window_box = ho::vector4f(0, 0, pipeline->window_dimensions[0], pipeline->window_dimensions[1]);

		// Are actions inside the window
		if(!point_inside_box(ho::vector2f(it->position[0], it->position[1]), window_box))
			it->action = ho::Application::Mouse::Actions::NONE;

		// Stretch the cursor coordinates if the game is set to stretch (graphics)
		if(pipeline->stretch) {
			it->position[0] = it->position[0] * pipeline->resolution[0] / pipeline->window_dimensions[0];
			it->position[1] = it->position[1] * pipeline->resolution[1] / pipeline->window_dimensions[1];
		}

		// Mouse mem
		switch(it->button) {
			case ho::Application::Mouse::Buttons::LEFT: {
				mouse_mem[0] = (it->action == ho::Application::Mouse::Actions::ACTIVE);
				break;
			}

			case ho::Application::Mouse::Buttons::MIDDLE: {
				mouse_mem[1] = (it->action == ho::Application::Mouse::Actions::ACTIVE);
				break;
			}

			case ho::Application::Mouse::Buttons::RIGHT: {
				mouse_mem[2] = (it->action == ho::Application::Mouse::Actions::ACTIVE);
				break;
			}
		}
	}
}

void Input::clear() {
	cursor_position = ho::vector2f().zero();
	memset(keyboard_mem, 0, sizeof(keyboard_mem));
	memset(mouse_mem, 0, sizeof(mouse_mem));
}
