#ifndef MATCH_H_INCLUDED
#define MATCH_H_INCLUDED

#include <vector>
#include "common.h"
#include "graphics.h"
#include "sound.h"
#include "input.h"
#include "player.h"
#include "enemy.h"
#include "bullet.h"
#include "explosion.h"
#include "particle.h"

#define MAX_STARS 20

class Game;

class Match {
public:
					Match(Pipeline* PIPELINE, Game* GAME);
					~Match();
	void 			update();
	void 			render();
	void 			add_player_bullet(Bullet* BULLET);
	void 			add_enemy_bullet(Bullet* BULLET);
	void 			add_score(int AMOUNT);
	void 			add_explosion(Explosion* EXPLOSION);
	ho::vector2f 	player_position();

private:
	void update_background();
	void update_bullets();
	void check_collisions();
	void update_enemies();
	void spawn_enemies();
	void update_explosions();
	void update_particles();

	Pipeline* 					pipeline;
	Game* 						game;
	ho::opengl::Primitive2d 	background;
	Player* 					player;
	std::vector<Enemy*> 		enemies;
	std::vector<Bullet*>		player_bullets;
	std::vector<Bullet*>		enemy_bullets;
	ho::Timer 					spawner_timer;
	int							score;
	ho::opengl::Font 			score_font;
	ho::opengl::Font 			high_score_font;
	std::vector<Enemy_type*> 	enemy_types;
	ho::Timer 					match_timer;
	float 						match_delta;
	std::vector<Explosion*> 	explosions;
	Particle				 	stars[MAX_STARS];
	std::vector<Particle*> 	particles;
};

#endif // MATCH_H_INCLUDED
