#include "menu.h"

MainMenu::MainMenu(Pipeline* PIPELINE) {
	pipeline = PIPELINE;
	start_button.set_texture(pipeline->graphics->get_texture("start_button"));
	exit_button.set_texture(pipeline->graphics->get_texture("exit_button"));
	menu_state = States::NONE;
}

void MainMenu::update() {
	pipeline->clip_cursor = false;
	ho::vector2 resolution = pipeline->resolution;
	ho::vector2f button_size;
	ho::vector2f button_position;
	float button_offset_y = 100;
	ho::vector4f mouse_over_color = ho::vector4f(0, 1, 0, 1);

	// Start button
	button_size = start_button.get_dimensions();
	button_position[0] = (resolution[0] / 2) - (button_size[0] / 2);
	button_position[1] = button_offset_y;
	button_offset_y += button_size[1] + 20;
	start_button.set_position(button_position);
	start_button.set_rgba(ho::vector4f().one());

	// Exit button
	button_size = exit_button.get_dimensions();
	button_position[0] = (resolution[0] / 2) - (button_size[0] / 2);
	button_position[1] = button_offset_y;
	button_offset_y += button_size[1] + 20;
	exit_button.set_position(button_position);
	exit_button.set_rgba(ho::vector4f().one());

	// Mouse input
	bool mouse_over_start = point_inside_box(pipeline->input->cursor_position, start_button.get_position(), start_button.get_dimensions());
	bool mouse_over_exit = point_inside_box(pipeline->input->cursor_position, exit_button.get_position(), exit_button.get_dimensions());

	if(mouse_over_start) {
		start_button.set_rgba(mouse_over_color);
	}

	if(mouse_over_exit) {
		exit_button.set_rgba(mouse_over_color);
	}

	// Check buttons
	for(auto it = pipeline->input->mouse.begin(); it != pipeline->input->mouse.end(); ++it) {
		if(it->action == ho::Application::Mouse::Actions::ACTIVE) {
			switch(it->button) {
				case ho::Application::Mouse::Buttons::LEFT: {
					if(mouse_over_exit) {
						pipeline->closing = true;
						menu_state = States::EXIT;
					}

					if(mouse_over_start) {
						menu_state = States::START;
					}

					break;
				}
			}
		}
	}
}

void MainMenu::render() {
	pipeline->hud_canvas.add(start_button);
	pipeline->hud_canvas.add(exit_button);
}

MainMenu::States MainMenu::state() {
	return menu_state;
}
