#include "sound.h"

Sound::~Sound() {
	// Delete streams
	for(auto it = streams.begin(); it != streams.end(); ++it)
		delete it->second;

	// Delete sounds
	for(auto it = sounds.begin(); it != sounds.end(); ++it)
		delete it->second;
}

bool Sound::load(ho::Config &FACTORY) {
	auto sounds_section = FACTORY.get_section("sounds");

	if(!sounds_section) {
		std::cout << "[!] Sound::load: Could not find [sounds] section\n";

		return false;
	}

	for(auto it = sounds_section->begin(); it != sounds_section->end(); ++it) {
		if(!import_mp3(it->second, it->first))
			return false;
	}

	return true;
}

void Sound::play_sound(ho::String NAME) {
	auto find = streams.find(NAME);

	if(find == streams.end()) {
		std::cout << "[!] Sound::play_sound: \"" << NAME << "\" could not be found.\n";
	} else
		find->second->play();
}

bool Sound::import_mp3(ho::String FILENAME, ho::String NAME) {
	ho::Memfile* sound = new ho::Memfile(FILENAME.c_str());

	if(!sound->good()) {
		delete sound;
		std::cout << "[!] Sound::import_mp3: \"" << FILENAME << "\" could not be found.\n";

		return false;
	}

	ho::audio::Stream* stream = new ho::audio::Stream(sound, ho::audio::Stream::MP3);
	sounds.insert(std::pair<ho::String, ho::Memfile*>(NAME, sound));
	streams.insert(std::pair<ho::String, ho::audio::Stream*>(NAME, stream));

	return true;
}
